/*
   ; Test the gripper
   ; ================

   ;------------------------------------------------------------------------
   ; Author:    Franzi Edo.     The 03/04/98
   ; Modifs:
   ;
   ; Project:   KHEPERA
   ; Goal:              Test of the gripper driver.
   ;
   ; This module is (c) of Edoardo Franzi 1992-1999
   ; franzi@k-team.com
   ;
   ;------------------------------------------------------------------------
 */

#include	<sys/kos.h>
#include	<sys/gripper.h>
#include 	<stdlib.h>
#include 	<stdio.h>

#define         SENSORS        8
#define         NBMOTORS        2
#define         SCALING         400
#define         SPEED           20

uint32 vIDProcess[2];


/* Functions */
/* >>>>>>>>> */

void
functions (int nfunc)
{
  int32 status;
  uint8 vVersion, vRevision;
  uint8 elevation;

  switch (nfunc % 9)
    {
    case 0:
      status = gripper_getVersion ();
      if (status < 0)
	{
	  printf ("Network Communication Problem\r\n");
	}
      else
	{
	  vVersion = (uint8) (status >> 8);
	  vRevision = (uint8) (status);
	  printf ("Version %d.%d\r\n", vVersion, vRevision);
	}
      break;

    case 1:
      elevation = (uint8) tim_get_ticcount ();
      status = gripper_putArmPosition (elevation);
      if (status < 0)
	{
	  printf ("Network Communication Problem\r\n");
	}
      break;
    case 2:
      status = gripper_openGripper ();
      if (status < 0)
	{
	  printf ("Network Communication Problem\r\n");
	}
      break;
    case 3:
      status = gripper_closeGripper ();
      if (status < 0)
	{
	  printf ("Network Communication Problem\r\n");
	}
      break;
    case 4:
      status = gripper_getGripperPosition ();
      if (status < 0)
	{
	  printf ("Network Communication Problem\r\n");
	}
      else
	{
	  printf ("Position %d\r\n", (uint8) status);
	}
      break;
    case 5:
      status = gripper_getArmPosition ();
      if (status < 0)
	{
	  printf ("Network Communication Problem\r\n");
	}
      else
	{
	  printf ("Position %d\r\n", (uint8) status);
	}
      break;
    case 6:
      status = gripper_getObjectStatus ();
      if (status < 0)
	{
	  printf ("Network Communication Problem\r\n");
	}
      else
	{
	  printf ("Object %d\r\n", (uint8) status);
	}
      break;
    case 7:
      status = gripper_getObjectResistivity ();
      if (status < 0)
	{
	  printf ("Network Communication Problem\r\n");
	}
      else
	{
	  printf ("Resistivity %d\r\n", (uint8) status);
	}
      break;
    case 8:
      status = gripper_getJumperState ();
      if (status < 0)
	{
	  printf ("Network Communication Problem\r\n");
	}
      else
	{
	  printf ("Jumper %d\r\n", (uint8) status);
	}
      break;
    default:
      break;
    }

}

/*
 * Process 0
 * ^^^^^^^^^
 *
 * This process changes the state of the LED 0
 * every 500 ms.
 *
 */

void
process_0 ()
{

  for (;;)
    {
      tim_suspend_task (500);
      var_change_led (0);
    }
}

/*
 * Process 1
 * ^^^^^^^^^
 *
 * Launch a function.
 *
 */

void
process_1 ()
{
  int i = 0;

  for (;; i++)
    {
      tim_suspend_task (500);
      functions (i);
    }
}

/*
 * MAIN
 * ====
 *
 * - Initialise the used managers: tim & bios are initialised at the start-up.
 * - Launch all the processes.
 * - Kill the "main". At this moment only the launched processes are executed.
 *
 */

int
main (void)
{
  int32 status;

  /*
     --------------------------|------------------------------------------------|
   */

  static char prName_0[] = "User 0 process, EF-99                            Rev. 1.00\r\n";
  static char prName_1[] = "User 1 process, EF-99                            Rev. 1.00\r\n";


  mot_reset ();
  sens_reset ();
  msg_reset ();
  var_reset ();
  ser_reset ();
  str_reset ();
  gripper_reset ();

  status = install_task (prName_0, 800, process_0);
  if (status == -1)
    exit (0);
  vIDProcess[0] = (uint32) status;

  status = install_task (prName_1, 800, process_1);
  if (status == -1)
    exit (0);
  vIDProcess[1] = (uint32) status;

  return 0;
}
